@@ -25,7 +25,7 @@ class FlowuiKubernetesPodOperator(KubernetesPodOperator):
         self.running_operator_name = operator_name 
         self.repository_id = repository_id
         self.workflow_shared_storage = workflow_shared_storage
-        self.task_id_replaced = self.task_id.replace("_", "-") # doing this because airflow doesn't allow underscores in mount names
+        self.task_id_replaced = self.task_id.replace("_", "-").lower() # doing this because airflow doesn't allow underscores and upper case in mount names
         self.task_env_vars = kwargs.get('env_vars', [])
         # Shared Storage variables
         self.shared_storage_base_mount_path = '/home/shared_storage'
@@ -162,7 +162,8 @@ class FlowuiKubernetesPodOperator(KubernetesPodOperator):
             'FLOWUI_WORKFLOW_SHARED_STORAGE': self.workflow_shared_storage.json() if self.workflow_shared_storage else "",
             'FLOWUI_WORKFLOW_SHARED_STORAGE_SECRETS': str(storage_operator_secrets),
             'FLOWUI_K8S_INSTANTIATE_OP_KWARGS': str(self.task_env_vars.get('FLOWUI_K8S_INSTANTIATE_OP_KWARGS')),
-            'FLOWUI_WORKFLOW_RUN_SUBPATH': self.workflow_run_subpath
+            'FLOWUI_WORKFLOW_RUN_SUBPATH': self.workflow_run_subpath,
+            'AIRFLOW_UPSTREAM_TASKS_IDS_SHARED_STORAGE': str(self.shared_storage_upstream_ids_list),
         }
 
         self.shared_storage_sidecar_container_name = f"flowui-shared-storage-sidecar-{self.task_id_replaced}"
@@ -226,8 +227,8 @@ class FlowuiKubernetesPodOperator(KubernetesPodOperator):
                 output_value = upstream_xcoms_data[upstream_task_id][output_arg]
                 output_type = upstream_xcoms_data[upstream_task_id][f"{output_arg}_type"]
                 # If upstream output type is FilePath or DirectoryPath, we need to add the basic path prefix
-                if output_type in ["file-path", "directory-path"]:
-                    output_value = f"{self.shared_storage_base_mount_path}/{upstream_task_id}/results/{output_value}"
+                # if output_type in ["file-path", "directory-path"]:
+                #     output_value = f"{self.shared_storage_base_mount_path}/{upstream_task_id}/results/{output_value}"
                 updated_op_kwargs[k] = output_value
                 if upstream_task_id not in self.shared_storage_upstream_ids_list:
                     self.shared_storage_upstream_ids_list.append(upstream_task_id)
